utils

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Base64EncodeToFile

func Base64EncodeToFile(inputPath, outputPath string) error

Base64EncodeToFile reads a file at inputPath and writes its base64 encoded content to outputPath

func FileToBase64String

func FileToBase64String(filePath string) (string, error)

FileToBase64String reads a file at the given path and returns its base64 encoded string

func FileToBase64Writer

func FileToBase64Writer(filePath string, output io.Writer) error

FileToBase64Writer reads a file at the given path and writes its base64 encoded content to the provided writer

Types

This section is empty.

Jump to